@@ -19,15 +19,12 @@
 
 class BeamWavelengthItem : public BeamDistributionItem {
 public:
-    BeamWavelengthItem();
+    BeamWavelengthItem(bool onlySymmetricDistributions = false);
 
     void readFrom(QXmlStreamReader* r) override;
 
     //! Returns wavelength. In the case of distribution applied, returns its mean.
     double wavelength() const;
-
-protected:
-    BeamWavelengthItem(bool onlySymmetricDistributions);
 };
 
 #endif // BORNAGAIN_GUI_MODEL_BEAM_BEAMWAVELENGTHITEM_H
