@@ -359,7 +359,7 @@ void ScanningFunctionality::readScanFrom(QXmlStreamReader* r)
 //  ************************************************************************************************
 
 SpecularInstrumentItem::SpecularInstrumentItem()
-    : ScanningFunctionality(1)
+    : ScanningFunctionality(1e6)
 {
 }
 
