@@ -16,6 +16,7 @@
 #include "Device/Coord/ICoordSystem.h"
 #include "Device/Data/Datafield.h"
 #include "Device/Detector/SimulationAreaIterator.h" // roiIndex
+#include "Device/Histo/SimulationResult.h"
 #include "GUI/Model/Data/DataItemUtil.h"
 #include "GUI/Model/Data/IntensityDataItem.h"
 #include "GUI/Model/Data/SpecularDataItem.h"
@@ -237,7 +238,11 @@ void JobItem::copySimulationOptionsIntoJob(const SimulationOptionsItem& options)
 
 void JobItem::setResults(const SimulationResult& result)
 {
-    GUI::Model::DataItemUtil::setResults(simulatedDataItem(), result);
+    auto coord = simulatedDataItem()->currentCoord();
+    auto converter = instrumentItem()->createCoordSystem();
+    GUI::Model::DataItemUtil::updateAxesTitle(simulatedDataItem(), *converter, coord);
+    simulatedDataItem()->setDatafield(
+        new Datafield(converter->convertedAxes(coord), result.flatVector()));
     updateDataFileName();
 }
 
