@@ -73,9 +73,9 @@ QString minimizerTypeToName(MinimizerType type)
 namespace {
 
 QMap<QString /*algorithm*/, QString /*minimizer*/> algorithm_minimizer_map;
-void add_algorithm_from_minimizer_to_list_and_map(MinimizerType minimizer_type,
-                                                  QStringList& common_algorithms_list,
-                                                  QStringList& common_algorithms_descriptions)
+QString add_algorithm_from_minimizer_to_list_and_map(MinimizerType minimizer_type,
+                                                     QStringList& common_algorithms_list,
+                                                     QStringList& common_algorithms_descriptions)
 {
     QString minimizer_name = minimizerTypeToName(minimizer_type);
     QStringList algorithms = MinimizerItemCatalog::algorithmNames(minimizer_name);
@@ -87,6 +87,8 @@ void add_algorithm_from_minimizer_to_list_and_map(MinimizerType minimizer_type,
         common_algorithms_descriptions.append(descriptions[i]);
         algorithm_minimizer_map.insert(algorithms[i], minimizer_name);
     }
+    ASSERT(algorithms.size() > 0);
+    return algorithms.first();
 }
 void create_algorithm_list_and_map(QString& default_common_algorithm, QStringList& algorithms_list,
                                    QStringList& algorithms_descriptions)
@@ -124,13 +126,12 @@ void create_algorithm_list_and_map(QString& default_common_algorithm, QStringLis
     algorithms_descriptions.append(descr);
 
     // other algorithms
-    add_algorithm_from_minimizer_to_list_and_map(MinimizerType::Genetic, algorithms_list,
-                                                 algorithms_descriptions);
+    // choose genetic algorithm as defaut
+    default_common_algorithm = add_algorithm_from_minimizer_to_list_and_map(
+        MinimizerType::Genetic, algorithms_list, algorithms_descriptions);
 
     add_algorithm_from_minimizer_to_list_and_map(MinimizerType::GSLSimAn, algorithms_list,
                                                  algorithms_descriptions);
-
-    default_common_algorithm = algorithms_list[1]; // after the first header: Minuit2 Migrad
 }
 
 } // namespace
@@ -145,12 +146,12 @@ MinimizerContainerItem::MinimizerContainerItem()
     QString default_common_algorithm;
     QStringList common_algorithms_list;
     QStringList common_algorithms_descriptions;
+    QString default_minimizer = minimizerTypeToName(MinimizerType::Genetic);
     create_algorithm_list_and_map(default_common_algorithm, common_algorithms_list,
                                   common_algorithms_descriptions);
     m_algorithm = ComboProperty::fromList(common_algorithms_list, default_common_algorithm);
     m_algorithm.setToolTips(common_algorithms_descriptions);
 
-    QString default_minimizer = minimizerTypeToName(MinimizerType::Minuit2);
     m_minimizer = ComboProperty::fromList(minimizer_names_map.keys(), default_minimizer);
     m_metric = ComboProperty::fromStdVec(ObjectiveMetricUtil::metricNames(),
                                          ObjectiveMetricUtil::defaultMetricName());
