@@ -27,7 +27,7 @@ class SphericalAxisForm;
 class AlphaScanEditor : public QGroupBox {
     Q_OBJECT
 public:
-    AlphaScanEditor(QWidget* parent, GrazingScanItem* item);
+    AlphaScanEditor(QWidget* parent, GrazingScanItem* item, bool allow_distr);
 
     void updateIndicators();
 
