@@ -37,7 +37,7 @@ signals:
 
 private:
     DoubleSpinBox* createSpinBox(DoubleProperty& d);
-    void addPolarizerRow(QFormLayout* parentLayout, VectorProperty& d);
+    void addBlochRow(QFormLayout* parentLayout, VectorProperty& d);
 
     InstrumentItem* m_instrument;
 };
