@@ -26,7 +26,7 @@ class ScanEditor : public QGroupBox {
     Q_OBJECT
 
 public:
-    ScanEditor(QWidget* parent, ScanItem* item, InstrumentNotifier* ec);
+    ScanEditor(QWidget* parent, ScanItem* item, InstrumentNotifier* ec, bool allow_distr = true);
 
 signals:
     void dataChanged();
